﻿using esoft.Class;
using esoft.Entities;
using System;
using System.Collections.Generic;
using System.Data.Entity.Core.Common.CommandTrees;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace esoft.Pages
{
    /// <summary>
    /// Логика взаимодействия для AddEditServicePage.xaml
    /// </summary>
    public partial class AddEditServicePage : Page
    {
        ActualContext actualContext = new ActualContext(); //Контекст таблиц
        TaskFill tasks = new TaskFill(); //полученный контекст формы
        List<TaskFill> taskContext = new List<TaskFill>(); //Список задач

        public AddEditServicePage()
        {
            InitializeComponent();
            FillForm();
        }

        private void FillForm()
        {
            cbStatus.ItemsSource = StatusTask.FillStatus();

            List<User> usersExecutor = actualContext.Users.Where(user => actualContext.Executor.Any(ex => ex.ID == user.ID)).ToList(); // Получение списка исполнителей
            cbExecutor.ItemsSource = UserInFIO.GroupUser(usersExecutor);

            List<User> usersManager = actualContext.Users.Where(user => actualContext.Manager.Any(manager => manager.ID == user.ID)).ToList(); // Получение списка менеджеров
            cbManager.ItemsSource = UserInFIO.GroupUser(usersManager);
        }

        private void BtnSaveTask_Click(object sender, RoutedEventArgs e)
        {
            // Получение значений из элементов управления формы
            string title = TBoxTitle.Text;
            string executorName = cbExecutor.SelectedItem?.ToString();
            string managerName = cbManager.SelectedItem?.ToString();
            string status = cbStatus.Text;
            int complexity = (int)IUDComplexityTask.Value;
            int time = (int)IUDTimeTask.Value;
            string nature = cbNatureTask.SelectedItem?.ToString();
            string description = TBoxDescription.Text;
            DateTime createDate = DPickerDateCreate.SelectedDate ?? DateTime.Now;
            DateTime deadline = DPickerDateDeadLine.SelectedDate ?? DateTime.Now;

            // Проверка на заполнение обязательных полей
            if (string.IsNullOrWhiteSpace(title) || string.IsNullOrWhiteSpace(executorName) || string.IsNullOrWhiteSpace(managerName) || string.IsNullOrWhiteSpace(status))
            {
                MessageBox.Show("Пожалуйста, заполните все обязательные поля!", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return;
            }

            // Поиск исполнителя и менеджера по их именам в контексте
            var executor = actualContext.Executor.FirstOrDefault(ex => ex.User.Name == executorName);
            var manager = actualContext.Manager.FirstOrDefault(m => m.User.Name == managerName);

            // Проверка на наличие исполнителя и менеджера
            if (executor == null || manager == null)
            {
                MessageBox.Show("Исполнитель или менеджер не найден!", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
                return;
            }

            // Создание новой задачи на основе введенных данных
            esoft.Entities.Task newTask = new esoft.Entities.Task
            {
                Title = title,
                ExecutorID = executor.ID,
                // Добавьте или измените свойства для ManagerID, если это необходимо
                Status = status,
                Difficulty = complexity,
                Time = time,
                WorkType = nature,
                Description = description,
                CreateDateTime = createDate,
                Deadline = deadline
            };

            // Добавление задачи в контекст базы данных
            var context = esoftEntities.GetContext();
            context.Task.Add(newTask);

            try
            {
                context.SaveChanges(); // Сохранение изменений в базе данных
                MessageBox.Show("Задача успешно добавлена!", "Успех", MessageBoxButton.OK, MessageBoxImage.Information);
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Ошибка при добавлении задачи: {ex.Message}", "Ошибка", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }
    }
}
